aboutsummaryrefslogtreecommitdiff
path: root/make-distribution.sh
diff options
context:
space:
mode:
authorPatrick Wendell <pwendell@gmail.com>2014-01-03 21:29:33 -0800
committerPatrick Wendell <pwendell@gmail.com>2014-01-03 21:29:33 -0800
commit604fad9c39763012d97b404941f7ba7137ec2eed (patch)
treea327c39fcf9ac53e17fbeb5dfedb11e04f505f3c /make-distribution.sh
parent9e6f3bdcda1ab48159afa4f54b64d05e42a8688e (diff)
parentc4d6145f7fde8a516024e886314bf8fecde817ea (diff)
downloadspark-604fad9c39763012d97b404941f7ba7137ec2eed.tar.gz
spark-604fad9c39763012d97b404941f7ba7137ec2eed.tar.bz2
spark-604fad9c39763012d97b404941f7ba7137ec2eed.zip
Merge remote-tracking branch 'apache-github/master' into remove-binaries
Conflicts: core/src/test/scala/org/apache/spark/DriverSuite.scala docs/python-programming-guide.md
Diffstat (limited to 'make-distribution.sh')
-rwxr-xr-xmake-distribution.sh11
1 files changed, 4 insertions, 7 deletions
diff --git a/make-distribution.sh b/make-distribution.sh
index 8ae8a4cf74..6c466c8a06 100755
--- a/make-distribution.sh
+++ b/make-distribution.sh
@@ -31,10 +31,10 @@
#
# Recommended deploy/testing procedure (standalone mode):
# 1) Rsync / deploy the dist/ dir to one host
# 2) cd to deploy dir; ./bin/start-master.sh
# 3) Verify master is up by visiting web page, ie http://master-ip:8080. Note the spark:// URL.
-# 4) ./bin/start-slave.sh 1 <<spark:// URL>>
-# 5) MASTER="spark://my-master-ip:7077" ./spark-shell
+# 4) ./sbin/start-slave.sh 1 <<spark:// URL>>
+# 5) MASTER="spark://my-master-ip:7077" ./bin/spark-shell
#
# Figure out where the Spark framework is installed
@@ -107,10 +107,7 @@ mkdir "$DISTDIR"/conf
cp "$FWDIR"/conf/*.template "$DISTDIR"/conf
cp -r "$FWDIR/bin" "$DISTDIR"
cp -r "$FWDIR/python" "$DISTDIR"
-cp "$FWDIR/spark-class" "$DISTDIR"
-cp "$FWDIR/spark-shell" "$DISTDIR"
-cp "$FWDIR/spark-executor" "$DISTDIR"
-cp "$FWDIR/pyspark" "$DISTDIR"
+cp -r "$FWDIR/sbin" "$DISTDIR"
if [ "$MAKE_TGZ" == "true" ]; then
@@ -31,10 +31,10 @@
# Recommended deploy/testing procedure (standalone mode):
# 1) Rsync / deploy the dist/ dir to one host
-# 2) cd to deploy dir; ./bin/start-master.sh
+# 2) cd to deploy dir; ./sbin/start-master.sh
# 3) Verify master is up by visiting web page, ie http://master-ip:8080. Note the spark:// URL.